pub fn apply_authorized_force_set_current_code<T: Config>(
para: Id,
new_code: ValidationCode,
)Expand description
Applies the already authorized current code for the parachain,
triggering the same functionality as force_set_current_code.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::apply_authorized_force_set_current_code.