pub fn authorize_force_set_current_code_hash<T: Config>(
para: Id,
new_code_hash: ValidationCodeHash,
valid_period: BlockNumberFor<T>,
)Expand description
Sets the storage for the authorized current code hash of the parachain.
If not applied, it will be removed at the System::block_number() + valid_period block.
This can be useful, when triggering Paras::force_set_current_code(para, code)
from a different chain than the one where the Paras pallet is deployed.
The main purpose is to avoid transferring the entire code Wasm blob between chains.
Instead, we authorize code_hash with root, which can later be applied by
Paras::apply_authorized_force_set_current_code(para, code) by anyone.
Authorizations are stored in an overwriting manner.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::authorize_force_set_current_code_hash.